summaryrefslogtreecommitdiff
path: root/lib/gnutls_ui.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/gnutls_ui.c')
-rw-r--r--lib/gnutls_ui.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/gnutls_ui.c b/lib/gnutls_ui.c
index 059e608823..3a7bc7ce68 100644
--- a/lib/gnutls_ui.c
+++ b/lib/gnutls_ui.c
@@ -172,20 +172,20 @@ int gnutls_x509pki_get_certificate_request_status(GNUTLS_STATE state)
/**
* gnutls_fingerprint_calc - This function calculates the fingerprint of the given data
* @algo: is a digest algorithm
* @data: is the data
* @result: is the place where the result will be copied.
* @result_size: should hold the size of the result. The actual size
* of the returned result will also be copied there.
*
- * This function will calculate a fingerprint (actually hash), of the
- * given data. The result is not printable data. You should convert
- * it to hex, or something else printable.
+ * This function will calculate a fingerprint (actually a hash), of the
+ * given data. The result is not printable data. You should convert it
+ * to hex, or to something else printable.
* Returns a negative value in case of an error.
*
**/
-int gnutls_fingerprint_calc(DigestAlgorithm algo, gnutls_datum data, char* result, int* result_size)
+int gnutls_fingerprint(DigestAlgorithm algo, const gnutls_datum* data, char* result, int* result_size)
{
GNUTLS_HASH_HANDLE td;
int hash_len = gnutls_hash_get_algo_len(algo);
@@ -199,7 +199,7 @@ int gnutls_fingerprint_calc(DigestAlgorithm algo, gnutls_datum data, char* resul
td = gnutls_hash_init( algo);
if (td==NULL) return GNUTLS_E_HASH_FAILED;
- gnutls_hash( td, data.data, data.size);
+ gnutls_hash( td, data->data, data->size);
gnutls_hash_deinit( td, result);
@@ -172,20 +172,20 @@ int gnutls_x509pki_get_certificate_request_status(GNUTLS_STATE state)
/**
- * gnutls_fingerprint_calc - This function calculates the fingerprint of the given data
+ * gnutls_fingerprint - This function calculates the fingerprint of the given data
* @algo: is a digest algorithm
* @data: is the data